CREATE TABLE jabber_connected_user (
	user_id INT NOT NULL CONSTRAINT userid_fk REFERENCES "user"(user_id),
	PRIMARY KEY (user_id)
);

CREATE TABLE jabber_project_log (
	jabber_project_log_id SERIAL NOT NULL,
	project_id INT NOT NULL CONSTRAINT projectid_fk REFERENCES project(project_id) ON DELETE CASCADE,
	message_date TIMESTAMP NOT NULL DEFAULT NOW(),
	message TEXT,
	PRIMARY KEY(jabber_project_log_id)
);

CREATE INDEX jabberprojectlog_projectiddate ON jabber_project_log(project_id,message_date);

CREATE TABLE jabber_project_log_idx (
	jabber_project_log_id INTEGER CONSTRAINT jabberprojectlogid_fk REFERENCES jabber_project_log(jabber_project_log_id) ON DELETE CASCADE,
	vectors tsvector
);

DELETE FROM jabber_project_log_idx;
INSERT INTO jabber_project_log_idx(jabber_project_log_id, vectors)
	(SELECT jabber_project_log_id, to_tsvector('default', COALESCE(message,'')) AS vectors FROM jabber_project_log);



CREATE OR REPLACE FUNCTION update_vectors() RETURNS TRIGGER AS '
DECLARE
table_name TEXT;
BEGIN
	table_name := TG_ARGV[0];
	-- **** tracker_item table ****
	IF table_name = ''tracker_item'' THEN
		IF TG_OP = ''INSERT'' THEN
			INSERT INTO tracker_item_idx (tracker_item_id, tracker_id, vectors) VALUES (NEW.tracker_item_id, NEW.tracker_id, to_tsvector(\'default\', coalesce(NEW.details,\'\') ||\' \'|| coalesce(NEW.summary,\'\')));
		ELSIF TG_OP = ''UPDATE'' THEN
			UPDATE tracker_item_idx SET tracker_id=NEW.tracker_id, vectors=to_tsvector(\'default\', coalesce(NEW.details,\'\') ||\' \'|| coalesce(NEW.summary,\'\')) WHERE tracker_item_id=NEW.tracker_item_id;
		END IF;	
	-- **** tracker_item_message table ****
	ELSIF table_name = ''tracker_item_message'' THEN
		IF TG_OP = ''INSERT'' THEN
			INSERT INTO tracker_item_message_idx (tracker_item_message_id, tracker_item_id, vectors) VALUES (NEW.tracker_item_message_id, NEW.tracker_item_id, to_tsvector(\'default\', coalesce(NEW.body,\'\')));
		ELSIF TG_OP = ''UPDATE'' THEN
			UPDATE tracker_item_message_idx SET tracker_item_id=NEW.tracker_item_id, vectors=to_tsvector(\'default\', coalesce(NEW.body,\'\')) WHERE tracker_item_message_id=NEW.tracker_item_message_id;
		END IF;		
	-- **** docman_file table ****
	ELSIF table_name = ''docman_file'' THEN
		IF TG_OP = ''INSERT'' THEN
			INSERT INTO docman_file_idx (docman_file_id, vectors) VALUES (NEW.docman_file_id, to_tsvector(\'default\', coalesce(NEW.description,\'\')));
		ELSIF TG_OP = ''UPDATE'' THEN
			UPDATE docman_file_idx SET vectors=to_tsvector(\'default\', coalesce(NEW.description,\'\')) WHERE docman_file_id=NEW.docman_file_id;
		END IF;		
	-- **** docman_file_version table ****
	ELSIF table_name = ''docman_file_version'' THEN
		IF TG_OP = ''INSERT'' THEN
			INSERT INTO docman_file_version_idx (docman_file_version_id, vectors) VALUES (NEW.docman_file_version_id, to_tsvector(\'default\', coalesce(NEW.changes,\'\')));
		ELSIF TG_OP = ''UPDATE'' THEN
			UPDATE docman_file_version_idx SET vectors=to_tsvector(\'default\', coalesce(NEW.changes,\'\')) WHERE docman_file_version_id=NEW.docman_file_version_id;
		END IF;		
	-- **** filesystem table ****
	ELSIF table_name = ''filesystem'' THEN
		IF TG_OP = ''INSERT'' THEN
			INSERT INTO filesystem_idx (filesystem_id, vectors) VALUES (NEW.filesystem_id, to_tsvector(\'default\', coalesce(NEW.strings,\'\')));
		ELSIF TG_OP = ''UPDATE'' THEN
			UPDATE filesystem_idx SET vectors=to_tsvector(\'default\', coalesce(NEW.strings,\'\')) WHERE filesystem_id=NEW.filesystem_id;
		END IF;		
	-- **** forum message table ****
	ELSIF table_name = ''forum_message'' THEN
		IF TG_OP = ''INSERT'' THEN
			INSERT INTO forum_message_idx (forum_message_id, forum_thread_id, vectors) VALUES (NEW.forum_message_id, NEW.forum_thread_id, to_tsvector(\'default\', coalesce(NEW.subject,\'\') ||\' \'|| coalesce(NEW.body,\'\')));
		ELSIF TG_OP = ''UPDATE'' THEN
			UPDATE forum_message_idx SET vectors=to_tsvector(\'default\', coalesce(NEW.subject,\'\') ||\' \'|| coalesce(NEW.body,\'\')) WHERE forum_message_id=NEW.forum_message_id;
		END IF;
	-- **** frs_release table ****
	ELSIF table_name = ''frs_release'' THEN
		IF TG_OP = ''INSERT'' THEN
			INSERT INTO frs_release_idx (frs_release_id, vectors) VALUES (NEW.frs_release_id, to_tsvector(\'default\', coalesce(NEW.changes,\'\') ||\' \'|| coalesce(NEW.release_notes,\'\') ||\' \'|| coalesce(NEW.release_name,\'\')));
		ELSIF TG_OP = ''UPDATE'' THEN
			UPDATE frs_release_idx SET vectors=to_tsvector(\'default\', coalesce(NEW.changes,\'\') ||\' \'|| coalesce(NEW.release_notes,\'\') ||\' \'|| coalesce(NEW.release_name,\'\')) WHERE frs_release_id=NEW.frs_release_id;
		END IF;
	ELSIF table_name = ''snippet'' THEN
		IF TG_OP = ''INSERT'' THEN
			INSERT INTO snippet_idx (snippet_id, vectors) VALUES (NEW.snippet_id, to_tsvector(\'default\', coalesce(NEW.snippet_name,\'\') ||\' \'|| coalesce(NEW.snippet_description,\'\')));
		ELSIF TG_OP = ''UPDATE'' THEN
			UPDATE snippet_idx SET vectors=to_tsvector(\'default\', coalesce(NEW.snippet_name,\'\') ||\' \'|| coalesce(NEW.snippet_description,\'\')) WHERE snippet_id=NEW.snippet_id;
		END IF;		
	-- **** projects table ****
	ELSIF table_name = ''project'' THEN
		IF TG_OP = ''INSERT'' THEN
			INSERT INTO projects_idx (project_id, vectors) VALUES (NEW.project_id, to_tsvector(\'default\', coalesce(NEW.project_name,\'\') ||\' \'|| coalesce(NEW.description,\'\') ||\' \'|| coalesce(NEW.unix_name,\'\')));
		ELSIF TG_OP = ''UPDATE'' THEN
			UPDATE projects_idx SET vectors=to_tsvector(\'default\', coalesce(NEW.project_name,\'\') ||\' \'|| coalesce(NEW.description,\'\') ||\' \'|| coalesce(NEW.unix_name,\'\')) WHERE project_id=NEW.project_id;
		END IF;
	-- **** news table ****
	ELSIF table_name = ''news'' THEN
		IF TG_OP = ''INSERT'' THEN
			INSERT INTO news_idx (news_id, vectors) VALUES (NEW.news_id, to_tsvector(\'default\', coalesce(NEW.summary,\'\') ||\' \'|| coalesce(NEW.details,\'\')));
		ELSIF TG_OP = ''UPDATE'' THEN
			UPDATE news_idx SET vectors=to_tsvector(\'default\', coalesce(NEW.summary,\'\') ||\' \'|| coalesce(NEW.details,\'\')) WHERE news_id=NEW.news_id;
		END IF;
	-- **** users table ****
	ELSIF table_name = ''"user"'' THEN
		IF TG_OP = ''INSERT'' THEN
			INSERT INTO users_idx (user_id, vectors) VALUES (NEW.user_id, to_tsvector(\'default\', coalesce(NEW.unix_name,\'\') ||\' \'|| coalesce(NEW.firstname,\'\') ||\' \'|| coalesce(NEW.lastname,\'\') ));
		ELSIF TG_OP = ''UPDATE'' THEN
			UPDATE users_idx SET vectors=to_tsvector(\'default\', coalesce(NEW.unix_name,\'\') ||\' \'|| coalesce(NEW.firstname,\'\') ||\' \'|| coalesce(NEW.lastname,\'\') ) WHERE user_id=NEW.user_id;
		END IF;
	-- **** jabber project log ****
	ELSIF table_name = ''jabber_project_log'' THEN
		IF TG_OP = ''INSERT'' THEN
			INSERT INTO jabber_project_log_idx (jabber_project_log_id, vectors) VALUES (NEW.jabber_project_log_id, to_tsvector(\'default\', coalesce(NEW.message,\'\') ));
		ELSIF TG_OP = ''UPDATE'' THEN
			UPDATE jabber_project_log_idx SET vectors=to_tsvector(\'default\', coalesce(NEW.message)) WHERE jabber_project_log_id=NEW.jabber_project_log_id;
		END IF;
	END IF;

	RETURN NEW;
END;'
LANGUAGE 'plpgsql';


CREATE TRIGGER jabber_project_log_ts_update AFTER UPDATE OR INSERT ON jabber_project_log
FOR EACH ROW EXECUTE PROCEDURE update_vectors('jabber_project_log');

ALTER TABLE tracker_extra_field ADD COLUMN use_commit_rule BOOLEAN;
ALTER TABLE tracker_extra_field ALTER COLUMN use_commit_rule SET DEFAULT FALSE;
UPDATE tracker_extra_field SET use_commit_rule=false;
ALTER TABLE tracker_extra_field_element ADD COLUMN can_commit BOOLEAN;
ALTER TABLE tracker_extra_field_element ALTER COLUMN can_commit SET DEFAULT FALSE;
UPDATE tracker_extra_field_element SET can_commit=false;
