<?php

class DocmanTreeRenderer {

	private $project;
	private $nested_folders;
	private $arranged_folders;
	private $current_folder_id = 0;
	private $parent_folders = array();	

	function __construct ($project, $nested_folders, $arranged_folders) {
		$this->project = $project;
		$this->nested_folders = $nested_folders;
		$this->arranged_folders = $arranged_folders;
	}

	/**
	 * renders navigation
	 *
	 * @param int $current -> id in the docman_folder table. current subdir. appears highlighted
	 * @param bool $in_admin -> tells us wether we're in the Admin area or not
	 * @return unknown
	 */

	function renderNavigation($current=0, $in_admin=false) {
		$this->current_folder_id = $current;
		$aStyle = ($this->current_folder_id == 0) ? ' style="font-weight:bold;"' : '';
		$link = GFUrl::getURL()->currentBaseUrl('');

		//$html = '<div class="docmanFolders">'."\n";
		$html='';
		$html .= '<ul style="margin:0px;padding-left:4px;" class="mktree" id="docmanMainTree">'."\n";
		//$html .= '<ul id="treemenu1" class="mktree" rel="open">'."\n";
		//$html .= '<li><a href="'.$link.'"'.$aStyle.'>['.Language::getSessText('Docman.RootFolder').']</a>'."\n";
		$aStyle = ($this->current_folder_id == 0) ? ' style="font-weight:bold;"' : '';
		$html .= '<li class="liOpen"><a '.$aStyle.' href="'.GFUrl::getURL()->currentBaseUrl('',array()).'">['.Language::getSessText('Docman.RootFolder').']</a>'."\n";
		$html .= $this->doFolder($this->arranged_folders, 0, $in_admin);
		//$html .= "</li></ul>\n</div>\n";
		$html .= "</li></ul>\n";
/*		$html .= '<script type="text/javascript">ddtreemenu.createTree("treemenu1", false);</script>' . "\n"; */
		return $html;
	}
	
	/**
	 * Get's an array with "arranged folders" and creates the HTML to display it
	 */
	function doFolder($folders, $parent_id, $in_admin=false) {
		$html = $expandLiId = '';
		$jsParentId = "jsDocmanParent{$parent_id}"; // parent_id for the JS code
		if (count($folders) > 0) {
			$this->parent_folders[] = $parent_id; // add to the array of parent folder ids			
			$html .=  '<ul ' . ($in_admin ? 'style="border:1px dotted #dddddd;margin-bottom:7px;padding-right:5px;"':'') . 'id="'.$jsParentId.'" >'."\n"; // UL containing this folder's content
			if($in_admin) {
				$html .= "<li style='visibility:hidden;'></li>\n";
			}
			$folders = $this->sortBySortOrder($folders); // sort the folders by its SortOrder
			foreach ($folders as $child) { // let's iterate the folders array
				$folder = $child['folder']; // let's get the actual folder
				$folder_id = $folder->getDocmanFolderId();
				// if we're not in the Admin page we should not have the JS Sorting code
				$liAux  = ($in_admin) ? ' id="jsDocmanParent0_'.$folder_id.'" class="jsDocmanFolder moveHandle"' : ' id="'.$jsParentId.'_FolderId'.$folder_id.'"';
				$aAux   = ($in_admin) ? " onclick=\"linkWatch(this.href); return false;\" onmouseover=\"doUnblockLink();return true;\"" : '';
				$hidden = ($in_admin) ? '<input type="hidden" id="FolderId'.$folder_id.'" name="folder_order['.$folder_id.']" value="'.$folder->getSortOrder().'"/>' : '';
				$aStyle = ($this->current_folder_id == $folder_id) ? ' style="font-weight:bold;"' : '';
				$expandLiClass='';
				if($this->current_folder_id == $folder_id) {
					$expandLiId = $jsParentId.'_FolderId'.$folder_id;
					$expandLiClass=' class="liOpen" ';
				}
				
				$link   = GFUrl::getURL()->currentBaseUrl('',array('subdir'=>$folder_id));
				// Now let's build the LI for this folder
				$html .= '<li'.$expandLiClass.$liAux.'><a href="'.$link.'"'.$aStyle.$aAux.'>'.$folder->getFolderName().'</a>'.$hidden;
				// Let's build this folder's childs as well
				$html .= $this->doFolder($child['childs'], $folder_id, $in_admin).'</li>'."\n";
			}
			$html .= '</ul>'."\n";
		} elseif ($in_admin) {
			$html .=  "<ul style=\"border:1px dotted #dddddd;margin-bottom:7px;padding-right:5px; \" id=\"".$jsParentId."\"><li style='visibility:hidden;'></li></ul>\n"; // UL containing this folder's content
		}
		if($expandLiId!='') {
			$html .= '<script type="text/javascript">function docmanExpandTree(){expandToItem("docmanMainTree","'.$expandLiId.'");}</script>' . "\n";
		}
		return $html;
	}

	/**
	 * Sorts an array of "arranged folders" baded on the SortOrder of the folders
	 */
	function sortBySortOrder($folders) {
		$auxArray = array();
		$i = 0;
		foreach ($folders as $folder) {
			// This is done to correctly handle folders with the same SortOrder value
			// More precisely those with just 0 as the SortOrder, which is the default value
			// Kind of hacky but should work fine unless we have more than 1000 childs of the same parent
			$order = 10000 + ($folder['folder']->getSortOrder() * 1000) + $i;
			// Now let's put the folder in an array with this "modified" [order] value as the key
			$auxArray[$order] = $folder;
			$i++;
		}
		// Now let's sort the array based on its key
		ksort($auxArray);
		return $auxArray;
	}
	
	/**
	 * Returns an array with the parent_folder_id's of the folders that are "sortable"
	 */
	function getSortables() {
		// Let's return the array in the reverse order that they were added
		// This is needed for the Javascript code to behave correctly.
		return array_reverse($this->parent_folders);
	}
	
}

?>
