<?php

require_once('DocmanFile.php');
require_once('DocmanFolderPeer.php');
require_once('DocmanFileVersion.php');

class InfoParser {

	private $project;
	private $elements = array();

	function __construct($Project) {
		$this->project = $Project;
		$logged_in = Session::getSession()->isLoggedIn();

		// Get all docman folders for this project
		$c = new Criteria();
		$c->add(DocmanFolderPeer::PROJECT_ID, $Project->getProjectId());
		$c->addAscendingOrderByColumn(DocmanFolderPeer::SORT_ORDER);
		$allelements = DocmanFolderPeer::doSelect($c);

		// If User is not member of this project, don't show private folders
		foreach ($allelements as $element) {
			if ($element->userCanRead()) {
				$this->elements[] = $element;
			}
		}
	}

	/**
	 * returns the folders in arrays where each child belongs to its parent array
	 */
	function getArrangedFolders() {
		$sortedFolders = $this->sortFolders($this->elements);
		return $sortedFolders;
	}
	
	
	
	/* Old sorting code follows...*/
	/**
	 * Sorts the given folders in arrays with elements [folder] and [childs]
	 */
	/*function sortFolders($folders) {
		$main = array(); // this array holds the data of what will be the final array (result)
		$remains = array(); // this array is used to store the data that is yet to be processed
		
		foreach ($folders as $folder) { // first, let's add the "root" folders to the "main" array
			if ($folder->getParentFolderId() == 0) {
				$main[] = array('folder'=>$folder,'childs'=>array());
			} else { // if not "root", add it to the "remains" array
				$remains[] = $folder;
			}
		}

		while (count($remains) > 0) { // now let's process the remains
			foreach ($remains as $folder) {
				$res = $this->searchAndAdd($folder, $main, $remains); // let's try to put each folder in the proper "parent"
				$main = $res[0];
				$remains = $res[1];
			}
		}
		return $main;
	}*/
	
	/**
	 * Tries to find the parent folder for a folder and updates the "main" and "remains" arrays
	 */
	/*function searchAndAdd($folder, $main, $remains) {
		$result = array();
		for ($i=0;$i<count($main);$i++) { // let's iterate the "main" array trying to find the proper parent
			if ($main[$i]['folder']->getDocmanFolderId() == $folder->getParentFolderId()) { // if found, let's update the "main" array
				$main[$i]['childs'][] = array('folder'=>$folder, 'childs'=>array());
				$remains = $this->removeFromArray($remains, $folder); // remove the folder from the "remains" array as it has been moved to "main"
				break;
			} else { // if not found, let's keep on trying using the childs of the folders in "main"
				$res = $this->searchAndAdd($folder, $main[$i]['childs'], $remains);
				$main[$i]['childs'] = $res[0];
				$remains = $res[1];
			}
		}
		$result[] = $main;
		$result[] = $remains;
		return $result; // the result is an array with the updated "main" and "remains" arrays
	}*/

	/* New sorting code, adapted from ForumMessagePeer::buildThread */
	private function sortFolders($folders_aux) {
		// build the structures that will help us with recursion later
		$children = array();
		$folders = array();
		foreach ($folders_aux as $folder) {
			$parent_id = $folder->getParentFolderId();
			$folder_id = $folder->getDocmanFolderId();

			if (!isset($children[$parent_id])) $children[$parent_id] = array();
			$children[$parent_id][] = $folder_id;
			
			$folders[$folder_id] = $folder;
		}
		
		$result = array();
		self::buildThreadedRecursive($result, $folders, $children, 0, 0);
		
		return $result;

	}
	
	/* Adapted from ForumfolderPeer::buildThreadedRecursive */
	
	public static function buildThreadedRecursive(&$result, &$folders, &$children, $parent_id, $level) {
		if (!array_key_exists($parent_id, $children)) return;
		
		$arr = $children[$parent_id];
		$n = count($arr);
		for ($i=0; $i < $n; $i++) {
			$children_id = $arr[$i];
			$newFolderIndex = count($result);
			$result[$newFolderIndex] = array("folder" => $folders[$children_id], 'childs' => array());
			// now append this children's children (if any)
			if (array_key_exists($children_id, $children)) {
				self::buildThreadedRecursive($result[$newFolderIndex]['childs'], $folders, $children, $children_id, ($level+1));
			}
		}
	}
	

	/**
	 * Removes a folder from a given array
	 */
	function removeFromArray($arrFolders, $folder) {
		$result = array(); // new array that will be returned as the result
		foreach ($arrFolders as $auxFolder) { // let's iterate the folders array
			 // if it's the folder we want to remove, don't add it to the new array
			if ($auxFolder->getDocmanFolderId() != $folder->getDocmanFolderId()) {
				$result[] = $auxFolder;
			}
		}
		return $result;
	}

	/**
	 * Returns all the folders in an array, using the form [parent_id]=>[folder]
	 */
	function getNestedFolders() {
		$el = $this->elements;
		$count=count($el);
		$nest=array();
		for ($i=0; $i<$count; $i++) {
			if(!isset($nest[$el[$i]->getParentFolderId()])) {
				$nest[$el[$i]->getParentFolderId()] = array();
			}
			$nest[$el[$i]->getParentFolderId()][]=$el[$i];
		}
		return $nest;
	}
	
	public function getElements() {
		return $this->elements;
	}

	function getDocCount($dir) {
		$docmanfolder=DocmanFolderPeer::retrieveByPk($dir);
		if (is_object($docmanfolder) && !$docmanfolder->userCanRead()) {
			throw new PermissionDeniedException();
		}
       	
		$sql="SELECT COUNT(*)
			FROM docman_folder NATURAL JOIN docman_file df NATURAL JOIN docman_file_version dfv,
			filesystem fs
			WHERE df.docman_folder_id='$dir'
			AND docman_folder.project_id='".$this->project->getProjectId()."'
			AND fs.section='docmanfileversion'
			AND fs.ref_id=dfv.docman_file_version_id
			AND dfv.version_number=(SELECT max(version_number) FROM docman_file_version WHERE docman_file_id=df.docman_file_id AND is_approved=true)";
		$con = Propel::getConnection(DocmanFolderPeer::DATABASE_NAME);
		$stmt = $con->createStatement();
		$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_NUM);
		$rs->next();
		return $rs->getInt(1);
	}
	/**
	 * Returns all the documents in a folder
	 */
	function getDocs($dir, $paginator=null) {
		$docmanfolder=DocmanFolderPeer::retrieveByPk($dir);
		if (is_object($docmanfolder) && !$docmanfolder->userCanRead()) {
			throw new PermissionDeniedException();
		}
       	if(is_null($paginator)) {
       		$sqlaux = '';
       	} else {
			$sqlaux = $paginator->getSQL();
       	}
       	
		$sql="SELECT docman_file.description, docman_file.is_locked, docman_file_version.version_number,
			docman_file_version.created_by, docman_file_version.create_date, docman_file_version.docman_file_version_id, 
			docman_file.docman_file_id, docman_file.docman_folder_id, filesystem.*, \"user\".firstname || ' ' || \"user\".lastname as full_name
			FROM docman_folder NATURAL JOIN docman_file NATURAL JOIN docman_file_version, filesystem
			LEFT JOIN \"user\" ON \"user\".user_id=filesystem.posted_by
			WHERE docman_file.docman_folder_id='$dir'
			AND docman_folder.project_id='".$this->project->getProjectId()."'
			AND filesystem.section='docmanfileversion'
			AND filesystem.ref_id=docman_file_version.docman_file_version_id
			AND docman_file_version.version_number=(SELECT max(version_number) FROM docman_file_version WHERE docman_file_id=docman_file.docman_file_id AND is_approved=true) $sqlaux";

		$con = Propel::getConnection(DocmanFolderPeer::DATABASE_NAME);
		$stmt = $con->createStatement();
		$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_ASSOC);
		return $rs;

	}
}
?>
