<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version
 * @author Daniel Perez danielperez.arg@gmail.com
 * @date 2005-11-18
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('notification/GFNotification.php');
require_once("plugin/ActionManager.php");
require_once("FrsPackage.php");

class FrsPackageNotification implements GFNotification {
	private $FrsPackage;
	private $FrsRelease;
	private $Project;
	private $notificationType='frspackage';
	private $users;

	function __construct(FrsPackage $FrsPackage, FrsRelease $FrsRelease) {
		$this->FrsPackage = $FrsPackage;
		$this->FrsRelease = $FrsRelease;
		$this->Project = $FrsPackage->getProject();
	}

	/**
	 *	getNotificationMessage - construct a string of this message content.
	 *
	 *	@param	User
	 *	@return string
	 */
	function getNotificationMessage(User $User) {
		$url = GFUrl::getUrl();

		$body = "\n\nProject ". $this->FrsPackage->getProject()->getProjectName() ." (". $this->FrsPackage->getProject()->getUnixName() .") has  \n".
		"released the new version of package ".
		$this->FrsPackage->getPackageName() . 
		"\nYou can download it by following this link: ".
		"\n"  . $url->getFullUrl($url->projectUrl($this->Project, 'FrsReleaseView', 'frs','',array('release_id'=>$this->FrsRelease->getFrsReleaseId())), true) .
		"\n\n______________________________________________________________________".
		"\n\nYou received this email because you ".
		"\nrequested to be notified when new versions of this package ".
		"\nwere released. If you don't wish to be notified in the ".
		"\nfuture, please login to " . $url->getFullUrl($url->baseUrl('Login', '', 'account'), true) . " and click this link: ".
		"\n" . $url->getFullUrl($url->getMonitorURL(FrsPackage::SECTION, $this->FrsPackage->getPrimaryKey(), $url->projectUrl($this->Project), false), true);
		
		return $body;
	}
	
	/**
	 *	getNotificationSubject - construct a string of this message subject.
	 *
	 *	@param	User
	 *	@return string
	 */
	function getNotificationSubject(User $User) {
		
		$subject = "[" . $this->FrsPackage->getProject()->getUnixName() . " Release] " . $this->FrsPackage->getProject()->getProjectName();
		return $subject;
	}

	/**
	 *	getUsers - get an array of user objects to send the notification to
	 *	@return array
	 */
	public function getUsers() {
		return $this->FrsPackage->getMonitoringUsers(); // package or project monitors
	}
	
	/**
	 *	getSection - retrieves the section name of the package that the notification belongs to
	 *	@return string
	 */	
	function getSection() {
		return FrsPackage::SECTION;
	}
	
	/**
	 *	getRefId - retrieves the id of the package that the notification belongs to
	 *	@return int
	 */	
	function getRefId() {
		return $this->FrsPackage->getFrsPackageId();
	}

}

?>
