<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Tim Perdue tim@gforge.org
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
require_once('lib/html/ProjectTemplate.php');
require_once('lib/plugin/PluginResult.php');

class MailmanTemplate extends ProjectTemplate {

	/**
	 * Header - this subclasses header and just passes params and data that is specific
	 * to this template
	 * @param array array of parameters
	 */
	function header($params) {
		$params['selectedbottomtab']='mailman';
		$Lang = Session::getSession()->getLanguage();
		if (isset($params['title'])) {
			$params['title']=' '.$Lang->getText('Mailman.TabString').' > '.$params['title'];
		} else {
			Throw new exception('Missing title in mailman template');
		}

		//add a breadcrumb for the thread if we're in one
		if (isset($_REQUEST['thread_id']) && isset($params['list'])) {
			$list = $params['list'];
			$ft=ForumThreadPeer::retrieveByPk($_REQUEST['thread_id']);
			if (is_object($ft)) {
				$this->addBreadCrumb('<a href="'.GFUrl::getUrl()->projectUrl($params['project'],'ListThreads','mailman','',array('mailman_id' => $list->getMailmanId(), '_forum_action'=>'ForumMessageBrowse', 'thread_id'=>$_REQUEST['thread_id'])).'">'.$ft->getThreadName().'</a>');
			}
		}

		if (isset($params['list'])) {
			$list = $params['list'];
			$this->addBreadCrumb('<a href="'.GFUrl::getUrl()->projectUrl($params['project'],'ListThreads','mailman', '', array('mailman_id' => $list->getMailmanId())).'">'.$list->getListName().'</a>');
		}
	
		$this->addBreadCrumb('<a href="'.GFUrl::getUrl()->projectUrl($params['project'],'','mailman').'">'.$Lang->getText('Mailman.TabString').'</a>');
	
		return parent::header($params);
	}

	/**
	 *      getPluginNavElements - this overrides parent class and adds its own
	 *      plugin listener
	 *      @return PluginResultSet
	 */
	function getPluginNavElements($params) {
		$prs = parent::getPluginNavElements($params);
		$tprs = ActionManager::Notify('GET_MAILMAN_NAV_ELEMENTS',$params);
		foreach ($tprs as $pr) {
			$prs->addResult($pr);
		}
		return $prs;
	}

	/**
	 * getTemplateNavElements - this function can be overridden
	 * by subclasses so you can add navigation entries
	 * @return array - complex array of data.
	 */
	function getTemplateNavElements($params) {
		$ret = array();
		$elements = array();
		$lang = Session::getSession()->getLanguage();
		$url = GFurl::getUrl();

		$pine = $this->getPluginNavElements($params);
		foreach ($pine as $result) {
			$ret[]=$result->getResult();
		}

		if (!isset($params['project'])) {
			echo 'missing project param';
		} else {
			$crit = new Criteria();
			$crit->add(MailmanPeer::PROJECT_ID, $params['project']->getProjectId());
			$crit->addAscendingOrderByColumn(MailmanPeer::LIST_NAME );
			
			$lists = MailmanPeer::doSelect($crit);
			
			foreach($lists as $list) {
				if ($list->userCanRead()) {
					$subelements = array();
					$subelements[] = array('link'=> $url->projectURL($params['project'], 'ListThreads', 'mailman','', array('mailman_id'=>$list->getMailmanId())),
											'description' => $lang->getText('Mailman.View'));
					$subelements[] = array('link'=> '/mailman/listinfo/' . $list->getListName(),
											'description' => $lang->getText('Mailman.Subscription'));
											
					if ($params['project']->getPermission()->isAdmin()) {
						$subelements[] = array('link'=> GFUrl::getUrl()->projectURL($params['project'], '', 'mailman','admin',array('action'=>'MailmanEdit','id'=>$list->getMailmanId())), 'description'=>'Admin');
					}
				
					if (isset($params['list']) && $params['list']->getMailmanId() == $list->getMailmanId()) {
						$expanded=true;
					} else {
						$expanded=false;
					}
					
					/*if (isset($params['list']) && isset($params['forum'])) {
						// Viewing mesesages using forum engine
						$subelements[] = array('link' => GFUrl::getUrl()->currentUrl(array('_forum_action' => 'MessageArchive', 'forum_id' => $params['forum']->getPrimaryKey())),
						'description' => Language::getSessText('Mailman.ViewArchive'));
					}*/
					
					$elements[] = array('link'=>'',
					'description'=> $list->getListName(),
					'expandables' => $subelements,
					'expanded' => $expanded);
				}
			}
		}
		//show admin link for all forums
		if (Session::getSession()->isLoggedIn()) {
			if ($params['project']->getPermission()->isAdmin()) {
				$elements[] = array('link' => $url->projectURL($params['project'],'','mailman','admin', array()),
					'description' => $lang->getText('Tabs.Admin'));
			}
		}
						
		if (count($elements) > 0) {
			$ret[] = array(
				'title' => 'Mailman',
				'elements'=> $elements
			);
		}

		return $ret;
	}
}

?>
