<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: ScmModule.php 3391 2008-09-01 20:20:13Z jyerfino $
 * @author Tim Perdue tim@gforge.org
 * @date 2006-01-03
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
require_once 'plugins/scm/lib/om/BaseScmModule.php';
require_once("plugin/ActionManager.php");

/** 
 * The skeleton for this class was autogenerated by Propel  on:
 *
 * [Wed Jan  4 05:51:25 2006]
 *
 * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package plugins.scm.lib 
 */
class ScmModule extends BaseScmModule {
	private $invalid_data = array();

	/**
	 * Specifies if the current user can update this object's entry in the database
	 *
	 * @return bool
	 */
	public function userCanUpdate() {
		return $this->userIsAdmin();
	}
	
	/**
	 * Specifies if the current user can delete this object's entry from the database
	 *
	 * @return bool
	 */
	public function userCanDelete() {
		return $this->userIsAdmin();
	}

	/**
	 * If this person is an admin for this object
	 * @return boolean
	 */
	private function userIsAdmin() {
		return $this->getProject()->getPermission()->isAdmin();
	}	

	/**
	 * Removes this object from datastore and sets delete attribute. Informs the plugin manager.
	 * This method was added by propel_customizer.php.
	 * 
	 * @param Connection $con
	 * @return void
	 * @throws PropelException
	 * @see ScmModule::setDeleted()
	 * @see ScmModule::isDeleted()
	 */
	function delete($con = null) {
		if(!$this->userCanDelete()) {
			throw new PermissionDeniedException();
		}
		ActionManager::notify("SCM_MODULE_DELETE", $this);
		parent::delete($con);		
	}

	/**
	 * Stores the object in the database using the Propel methods. Informs the plugin manager.
	 * This method was added by propel_customizer.php.
	 *
	 * @param Connection $con
	 * @return void
	 * @throws PropelException
	 */
	function save($con = null) {
		$errors = array();
		
		if(!$this->userCanUpdate()) {
			throw new PermissionDeniedException();
		}

		if (is_null($this->project_id) || empty($this->project_id)) {
			$errors['project_id'] = Language::getSessText('User.EmptyUnixName');
		} else if (isset($this->path) && !empty($this->path)) {
			// Both path and project_id were set. Check for duplicates.
			if ($this->isNew() || in_array(ScmModulePeer::PATH, $this->modifiedColumns)) {
				$c = new Criteria();
				$c->add(ScmModulePeer::PATH, $this->path);
				$c->add(ScmModulePeer::PROJECT_ID, $this->project_id);
				$obj = ScmModulePeer::doSelectOne($c);
				if (!is_null($obj)) {
					$errors['path'] = Language::getSessText('ScmModule.DuplicatedPath');
				}
			}
		} else {
			$errors['path'] = Language::getSessText('ScmModule.EmptyPath');
		}
		
		$errors = array_merge($errors, $this->invalid_data);
		if (count($errors) > 0) {
			throw new InvalidDataException($errors);
		}

		ActionManager::notify("SCM_MODULE_SAVE_BEFORE", $this);
		parent::save($con);
		ActionManager::notify("SCM_MODULE_SAVE", $this);
	}
	
	function setPath($path) {
		if (empty($path) || $path[0] != '/') {
			$this->invalid_data['path'] = Language::getSessText('ScmModule.NoStartSlash');
			return;
		}
		
		parent::setPath($path);
		unset($this->invalid_data['path']);
	}
}
?>
