<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id:
 * @author Federico Tarantini	federico@gforgegroup.com
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('plugin/GFPlugin.php');
require_once('plugin/ActionManager.php');
require_once('plugin/PluginResult.php');
require_once('plugins/scm/lib/ScmPlugin.php');
require_once('core/Language.php');



class ScmccPlugin extends ScmPlugin {
	function __construct() {
	}	
	
	/**
	 *	Different types of plugins are possible -
	 *	GFPlugin::SITE_PLUGIN = 'site'
	 *	GFPlugin::PROJECT_PLUGIN = 'project'
	 *	GFPlugin::USER_PLUGIN = 'user'
	 */
	public function getType() {
		return GFPlugin::SCM_PLUGIN;
	}	
	
	/**
	 *	get the name of this plugin. example: 'tracker'
	 *	@return	string
	 */
	public function getName() {
		return 'scmcc';
	}

	/**
	 *	take a search object and handle the search internally.
	 *	@param	GFSearch
	 *	@return PluginResult
	 */
	public function search(GFSearch $search) {
	}
	
	
	/**
	 *	get project uri to be used as root for constructing uris
	 *	@return string
	 */
	function getProjectPluginUri() {
		return GFUrl::getUrl()->projectURL($this->project,'','scmcc');
	}

	protected function buildMainTabsListener($params) {
		$project = $params['project'];
		if (!$project->usesPlugin($this->getName())) return null;

		$result = new PluginResult($this);
		$value = array(
				'text'	=> Language::getSessText('Scmcc.TabString'),
				'action'	=> GFUrl::getUrl()->projectURL($project,'','scmcc'),
				'id'	=> 'cc'
			);
		$result->setResult($value);
		return $result;
	}

	/**
	 *      getScmNavElements - get the local nav elements for the tracker
	 *      @return PluginResult
	 */
	protected function getScmNavElements($params) {
		$lang = Language::getSessLang();
		
		$project = $params['project'];
		if (!$project->usesPlugin($this->getName())) return null;

		$url = GFurl::getUrl();
		$lang = Session::getSession()->getLanguage();
		$user = Session::getSession()->getUser();
		$loggedin = Session::getSession()->isLoggedIn();
		$project = $params['project'];		
		
		$elements = array(
						array(
							'link'=> GFUrl::getUrl()->projectUrl($project,'AccessInfo','scmcc'),
							'description' => $lang->getText('Scmcc.AccessInfo')
						),
						array(
							'link'=> GFUrl::getUrl()->projectUrl($project,'ScmCommitBrowse','scmcc'),
							'description' => $lang->getText('Scm.BrowseCommits')
						));
				
		if ($loggedin) {
			if ($project->getPermission()->isAdmin()) {
				$elements[] = array('link' => $url->projectURL($project,'','scmcc','admin', ''),
					'description' => $lang->getText('Tabs.Admin'));
			}
		}				
		
		$result = new PluginResult($this);
		$arr = array(
			'title'=> 'ScmCC',
			'elements'=> $elements
			);
		$result->setResult($arr);
		return $result;
	}
	
	protected function buildProjectSummary($params) {
		if (!isset($params['project']) || !is_object($params['project']) || !$params['project']->usesPlugin($this->getName())) {
			return;
		}

		$project = $params['project'];
		$theme = $params['theme'];
		
		$result = new PluginResult($this);
		$stats = $repos->getStats();
		
		$value = 'hola';

		$result->setResult($value);
		return $result;
	}

	/**
	 * 	The getObserverRoleChoices listener - this hook will fire
	 *	when the observer role is modified.
	 * 	It returns an array of role settings or null
	 *	@return	array or null
	 */
	function getObserverRoleChoices($params) {	
		return parent::getObserverRoleChoices($params);
	}
	
	/**
	 * Retrieves the concerning data and updates its observer role settings
	 *
	 * @param array	$data
	 */	
	function updateObserverSettings($data) {	
		return parent::updateObserverSettings($data);
	}		

	/**
	 *      getProjectAdminNavElements - get the local nav elements for the tracker
	 *      @return PluginResult
	 */
	protected function getProjectAdminNavElements($params) {
		if (!isset($params['project']) || !is_object($params['project']) || !$params['project']->usesPlugin($this->getName())) {
			return;
		}

		$lang = Session::getSession()->getLanguage();
		$url = GFUrl::getUrl();

		$result = new PluginResult($this);
		$arr = array(
			'title'=> $lang->getText('Scmcc.TabString'),
			'elements'=> array(
			array('link'=> $url->projectUrl($params['project'], '', $this->getName(), 'admin'),
				'description'=> $lang->getText('Scmcc.Admin'))
			)
		);
		$result->setResult($arr);
		return $result;
	}
	
}