<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Marcelo Mottalli <marcelo@gforgegroup.com>
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('lib/initialize.php');
require_once('system/Cronjob.php');
require_once('core/ProjectPeer.php');
require_once('core/PluginPeer.php');
require_once('core/ProjectPluginPeer.php');
require_once('plugins/scm/lib/ProjectScmPeer.php');
require_once('plugins/scmgit/lib/GITRepository.php');
require_once('GFConf.php');

class CreateGitRepositoriesCronjob extends Cronjob {
	private $repositoryPath, $gitRoot;
	
	const PLUGIN_NAME = "scmgit";
	
	public function __construct() {
		$this->jobname = basename(__FILE__);
		parent::__construct();
	}
	
	public function run() {
		$this->gitRoot = GFConf::get('scmgit.localGitRoot');
		
		
		// Loop through and create/update each repository for every project that uses the Git plugin
		if (is_dir($this->gitRoot)) {
			chmod($this->gitRoot, 0755);	// This allows repository browsing
			$this->updateGitRepositories();
		} elseif (is_file($this->gitRoot)) {
			$this->logCron($this->gitRoot." exists but is a file");
			$this->commitLog();
			exit(1);
		} else {
			// Need to create the Git root
			if (mkdir($this->gitRoot)) {
				chmod($this->gitRoot, 0755);
				$this->updateGitRepositories();
			} else {
				$this->logCron("Unable to create ".$this->gitRoot." directory");
				$this->commitLog();
				exit(1);
			}
		}
	}

	private function updateGitRepositories() {
		// lets get all projects that use the plugin
		$c = new Criteria();
		$c->add(PluginPeer::PLUGIN_NAME, self::PLUGIN_NAME);
		$project_plugins = ProjectPluginPeer::doSelectJoinPlugin($c);
		
		foreach ($project_plugins as $project_plugin) {
			$project = $project_plugin->getProject(); // get the project
			$gitplugin = $project->getPluginByName('scmgit');
			
			$repos = new GITRepository($project);
			// GIT not configured for this project
			if (is_null($repos) || !$repos->isConfigured()) {
				continue;
			}
			
			$project_scm = $repos->getScmConfiguration(); // get the scm configuration for this project
			
			// If we're splitting SCM servers, see if the repository for this project must be
			// created on this server
			if (GFConf::get('system.splitScmServers') && GFConf::varExists('scmgit.scmServerId')) {
				$repository_server_id = $project_scm->getScmServer()->getScmServerId();
				// This repository belongs to another server, don't create it
				if ($repository_server_id != GFConf::get('scmgit.scmServerId')) {
					continue;
				}
			}

			try {
				if ($project->isActive() && $project_scm->getControlled()) {
					if (!$repos->isCreated()) {
						$permissions = ($project->getIsPublic()) ? 02775 : 02770;
						$repos->create($permissions);
					} else {
						$repos->updateRepository();
					}

				}
			} catch (Exception $e) {
				$this->logCron($e->getMessage());
			}
		}
		
		$this->commitLog();
	}
}

$cronjob = new CreateGitRepositoriesCronjob();
$cronjob->run();
?>
