#!/usr/bin/php
<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Marcelo Mottalli <marcelo@gforgegroup.com>
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('initialize.php');
require_once('GFConf.php');
require_once('core/Project.php');
require_once('core/User.php');
require_once('core/Language.php');
require_once('exceptions/InvalidProjectException.php');
require_once('plugins/scm/lib/ScmCommitWrapper.php');
require_once('plugins/scmperforce/lib/PerforceConfigFile.php');
require_once('plugins/scmperforce/lib/PerforceManager.php');
require_once('plugins/scmperforce/lib/PerforceRepository.php');

if ($argc != 4) {
	echo "Usage: ".$argv[0]." <project> <changelist number> <user>\n";
	exit(1);
}

$project_name = $argv[1];
$changelist_num = $argv[2];
$username = $argv[3];

$user = UserPeer::retrieveByUnixName($username);

$project = ProjectPeer::retrieveByUnixName($project_name);
if (!is_object($project)) {
	throw new InvalidProjectException($project_name);
}

$repos = new PerforceRepository($project);

$manager = new PerforceManager();
$changelist_data = $manager->getChangelistData($changelist_num);

// Generate the commit data

$log = $changelist_data['log'];
if (array_key_exists($repos->getRepositoryName(), $changelist_data['changes'])) {
	$changed_files = $changelist_data['changes'][$repos->getRepositoryName()];
} else {
	$changed_files = array();
}

$files = array();
foreach ($changed_files as $file) {
	$files[] = array(
				'path' => $file['path'],
				'prev_version' => $file['oldrev'],
				'new_version' => $file['oldrev'] + 1
			);
}

$wrapper = new ScmCommitWrapper($repos, $user, $log, $files);
$wrapper->generateCommitData();

exit(0);
?>
