<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: Layout.php 270 2005-12-31 03:02:47Z tperdue $
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

// This code generates a SOAP API for handling JabberProjectLog

require_once('plugins/jabber/lib/JabberProjectLog.php');
require_once('plugins/jabber/lib/JabberProjectLogPeer.php');
require_once('Validator.php');

/* ******************************************************************** */
/*                                 DATA TYPES                           */
/* ******************************************************************** */
$server->wsdl->addComplexType(
	'JabberProjectLog',
	'complexType',
	'struct',
	'sequence',
	'',
	array(
		'jabber_project_log_id' => array('name'=>'jabber_project_log_id', 'type' => 'xsd:int'),
		'project_id' => array('name'=>'project_id', 'type' => 'xsd:int'),
		'message_date' => array('name'=>'message_date', 'type' => 'xsd:string'),
		'message' => array('name'=>'message', 'type' => 'xsd:string'),
	)
);


$server->wsdl->addComplexType(
	'ArrayOfJabberProjectLog',
	'complexType',
	'array',
	'',
	'SOAP-ENC:Array',
	array(),
	array(array('ref' => 'SOAP-ENC:arrayType', 'wsdl:arrayType' => 'tns:JabberProjectLog[]')),
	'tns:JabberProjectLog'
);

/* ******************************************************************** */
/*                                 METHODS                              */
/* ******************************************************************** */

$server->register(
	'getJabberProjectLogs',
	array(
		'sessionHash'	=> 'xsd:string',
		'project_id' => 'xsd:int',
		'message_date' => 'xsd:string',
	), 
	array('getJabberProjectLogs' => 'tns:ArrayOfJabberProjectLog'),
	$uri, 
	$uri.'#getJabberProjectLogs',
	'rpc',
	'encoded'
);


/**
 * SOAP method to retrieve a list of JabberProjectLog
 * @param	$project_id	Filter by project_id
 * @param	$message_date	Filter by message_date
 */
function getJabberProjectLogs($sessionHash, $project_id, $message_date) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	$PrjObj = ProjectPeer::retrieveByPK($project_id);
	if (is_null($PrjObj) || !$PrjObj->userCanRead()) {
		return new soap_fault('', 'getJabberProjectLogs','Permission Denied - Cannot View This Record','Permission Denied - Cannot View This Record');
	}

	$crit = new Criteria();
	$crit->add(JabberProjectLogPeer::PROJECT_ID, $project_id);

	if (!is_null($message_date) && $message_date != '') {
		$crit->add(JabberProjectLogPeer::MESSAGE_DATE, $message_date);
	}
	
	$objs = JabberProjectLogPeer::doSelect($crit);
	$res = array();
	foreach ($objs as $obj) {
		$res[] = JabberProjectLogToSOAP($obj);
	}
	return $res;
}

$server->register(
	'getJabberProjectLog',
	array(
		'sessionHash'	=> 'xsd:string',
		'project_id' => 'xsd:int',
		'jabber_project_log_id' => 'xsd:int',
	), 
	array('getJabberProjectLog' => 'tns:JabberProjectLog'),
	$uri, 
	$uri.'#getJabberProjectLog',
	'rpc',
	'encoded'
);

/**
 * SOAP method to retrieve a single JabberProjectLog
 * @param	$project_id
 * @param	$jabber_project_log_id	Retrieve the JabberProjectLog identified by this jabber_project_log_id
 */
function getJabberProjectLog($sessionHash, $project_id, $jabber_project_log_id) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	$PrjObj = ProjectPeer::retrieveByPK($project_id);
	if (is_null($PrjObj) || !$PrjObj->userCanRead()) {
		return new soap_fault('', 'getJabberProjectLog','Permission Denied - Cannot View This Record','Permission Denied - Cannot View This Record');
	}

	$obj = JabberProjectLogPeer::retrieveByPK($jabber_project_log_id);
	if (is_null($obj)) {
		return null;
	}
	return JabberProjectLogToSOAP($obj);
}

function JabberProjectLogToSOAP(&$obj) {
	$ret = array();
	$ret['jabber_project_log_id'] = $obj->getJabberProjectLogId();
	$ret['project_id'] = $obj->getProjectId();
	$ret['message_date'] = $obj->getMessageDate();
	$ret['message'] = $obj->getMessage();
	return $ret;
}
?>