 <?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Marcelo Mottalli <marcelo@gforgegroup.com>
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once("plugin/ActionManager.php");
require_once('session/Session.php');
require_once('exceptions/NotLoggedInException.php');
require_once('exceptions/MissingDataException.php');
require_once('lib/core/Monitor.php');
require_once('Validator.php');
require_once('html/ProjectTemplate.php');

$session = Session::getSession();

if (!isset($_GET['section']) || !isset($_GET['ref_id'])) {
	throw new MissingDataException();
}


if (!$session->isLoggedIn()) {
	throw new NotLoggedInException();
}

$Lang = $session->getLanguage();

$section = Validator::sanitizeString($_GET['section']);
$ref_id = Validator::sanitizeInt($_GET['ref_id']);
$description = Validator::sanitizeString($_GET['description']);
$type = Validator::sanitizeString($_GET['type']);

$project = GFUrl::getUrl()->getProject();
	
$params = array('section' => $section, 'ref_id' => $ref_id);
$prs = ActionManager::notify('MONITOR_CHECK_PERMISSIONS', $params);

$allow = false;
foreach ($prs as $pluginresult) {
	$can_monitor = $pluginresult->getResult();
	if ($can_monitor) {
		$allow = true;
		break;
	}
}


if (!$allow) {
		throw new PermissionDeniedException($Lang->getText('Monitor.UsersMonitoringNoPermission'));
}

$template = new ProjectTemplate();
	
$params = array(
	'project' => $project,
	'title'=> $Lang->getText('Monitor.Users')
);

$c = new Criteria();
$c->add(MonitorPeer::SECTION, $section);
$c->add(MonitorPeer::REF_ID, $ref_id);
$mon = MonitorPeer::doSelect($c);

$theme->header($params);

if ($type == 'item') {
	$title = $Lang->getText('Monitor.Title2').': '.$description.' [#'.$ref_id.']';
} else {
	$title = $Lang->getText('Monitor.Title1').': '.$description.' [#'.$ref_id.']';
}

echo '<br /><h4>'.$title.'</h4><br />';

$theader=array();
$theader[] = $Lang->getText('User.UnixName');
$theader[] = $Lang->getText('User.FirstnameName');
$theader[] = $Lang->getText('User.LastnameName');
echo $theme->tableTop($theader);

if (count($mon) < 1) {
	echo $theme->tableFullRow($Lang->getText('Monitoring.NoUsers'));
} else {

	foreach ($mon as $monitoring_user) {
		$c2 = new Criteria();
		$c2->add(UserPeer::USER_ID, $monitoring_user->getUserId());
		$user = UserPeer::doSelectOne($c2);
		
		$trow=array();
		$trow[]=$user->getUnixname();
		$trow[]=$user->getFirstName();
		$trow[]=$user->getLastName();
		echo $theme->tableRow($trow);
	}
}
echo $theme->tableBottom();

if (isset($_GET['return_to']) && Validator::validateRedirect($_GET['return_to'])) {
	$return_to = Validator::sanitizeString($_GET['return_to']);
	$return_to = str_replace("'","%27",$return_to);
	echo  HTMLWidget::button("button",$Lang->getText('Common.Back'),"cancel","","window.location='". $return_to. "';");
}

$theme->footer($params);
?>